begentle
========
begentle is a package for detecting toxic language using 
the Perspective API (more info at `PerspectiveAPI.com <https://perspectiveapi.com/>`_).
Google already has a Python module for this, but I think it's 
too complex, so I created my own.

